@@ -49,6 +49,7 @@ class School(models.Model):
     latitude = models.CharField(max_length=20)
     longitude = models.CharField(max_length=20)
     country = CountryField(blank_label="(select country)")
+    creation_time = models.DateTimeField(default=timezone.now, null=True)
 
     class Meta(object):
         permissions = (
@@ -71,7 +72,7 @@ class School(models.Model):
 
 
 class TeacherModelManager(models.Manager):
-    def factory(self, title, first_name, last_name, email, password):
+    def factory(self, first_name, last_name, email, password):
         user = User.objects.create_user(
             username=email,
             email=email,
@@ -82,11 +83,10 @@ class TeacherModelManager(models.Manager):
 
         user_profile = UserProfile.objects.create(user=user)
 
-        return Teacher.objects.create(user=user_profile, new_user=user, title=title)
+        return Teacher.objects.create(user=user_profile, new_user=user)
 
 
 class Teacher(models.Model):
-    title = models.CharField(max_length=35)
     user = models.OneToOneField(UserProfile, on_delete=models.CASCADE)
     new_user = models.OneToOneField(
         User,
@@ -147,6 +147,7 @@ class Class(models.Model):
     classmates_data_viewable = models.BooleanField(default=False)
     always_accept_requests = models.BooleanField(default=False)
     accept_requests_until = models.DateTimeField(null=True)
+    creation_time = models.DateTimeField(default=timezone.now, null=True)
 
     objects = ClassModelManager()
 
@@ -183,6 +184,17 @@ class Class(models.Model):
         verbose_name_plural = "classes"
 
 
+class UserSession(models.Model):
+    user = models.ForeignKey(User, on_delete=models.CASCADE)
+    login_time = models.DateTimeField(default=timezone.now)
+    school = models.ForeignKey(School, null=True, on_delete=models.SET_NULL)
+    class_field = models.ForeignKey(Class, null=True, on_delete=models.SET_NULL)
+    login_type = models.CharField(max_length=100, null=True)  # for student login
+
+    def __str__(self):
+        return f"{self.user} login: {self.login_time} type: {self.login_type}"
+
+
 class StudentModelManager(models.Manager):
     def get_random_username(self):
         while True:
@@ -190,14 +202,17 @@ class StudentModelManager(models.Manager):
             if not User.objects.filter(username=random_username).exists():
                 return random_username
 
-    def schoolFactory(self, klass, name, password):
+    def schoolFactory(self, klass, name, password, login_id=None):
         user = User.objects.create_user(
             username=self.get_random_username(), password=password, first_name=name
         )
         user_profile = UserProfile.objects.create(user=user)
 
         return Student.objects.create(
-            class_field=klass, user=user_profile, new_user=user
+            class_field=klass,
+            user=user_profile,
+            new_user=user,
+            login_id=login_id,
         )
 
     def independentStudentFactory(self, username, name, email, password):
@@ -223,6 +238,8 @@ class Student(models.Model):
     class_field = models.ForeignKey(
         Class, related_name="students", null=True, on_delete=models.CASCADE
     )
+    # hashed uuid used for the unique direct login url
+    login_id = models.CharField(max_length=64, null=True)
     user = models.OneToOneField(UserProfile, on_delete=models.CASCADE)
     new_user = models.OneToOneField(
         User,
