@@ -1,47 +1,14 @@
-# -*- coding: utf-8 -*-
-# Code for Life
-#
-# Copyright (C) 2021, Ocado Innovation Limited
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as
-# published by the Free Software Foundation, either version 3 of the
-# License, or (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# ADDITIONAL TERMS – Section 7 GNU General Public Licence
-#
-# This licence does not grant any right, title or interest in any “Ocado” logos,
-# trade names or the trademark “Ocado” or any other trademarks or domain names
-# owned by Ocado Innovation Limited or the Ocado group of companies or any other
-# distinctive brand features of “Ocado” as may be secured from time to time. You
-# must not distribute any modification of this program using the trademark
-# “Ocado” or claim any affiliation or association with Ocado or its employees.
-#
-# You are not authorised to use the name Ocado (or any of its trade names) or
-# the names of any author or contributor in advertising or for publicity purposes
-# pertaining to the distribution of this program, without the prior written
-# authorisation of Ocado.
-#
-# Any propagation, distribution or conveyance of this program must include this
-# copyright notice and these terms. You must not misrepresent the origins of this
-# program; modified versions of the program must be marked as such and not
-# identified as the original program.
 from builtins import range
 from typing import Tuple
+from uuid import uuid4
 
 from django.core import mail
 
 from common.helpers.emails import generate_token
 from common.models import Class, Student
 
+from common.helpers.generators import generate_login_id
+
 from . import email
 
 
@@ -74,6 +41,17 @@ def create_school_student_directly(access_code) -> Tuple[str, str, Student]:
     return name, password, student
 
 
+def create_student_with_direct_login(access_code) -> Tuple[Student, str]:
+    name, password = generate_school_details()
+    klass = Class.objects.get(access_code=access_code)
+
+    # use random string for direct login)
+    login_id, hashed_login_id = generate_login_id()
+    student = Student.objects.schoolFactory(klass, name, password, hashed_login_id)
+
+    return student, login_id, name, password
+
+
 def create_independent_student_directly(preverified=True):
     """
     Creates a Student object and makes it independent by generating random details.
